@@ -124,6 +124,9 @@ private:
 
 /** Amtrak staion codes. */
 using AmtrakStationCode = AlphaId<uint16_t, 3>;
-
+/** Via Rail station code. */
+using ViaRailStationCode = AlphaId<UnalignedNumber<3>, 4>;
+/** UK railway station code. */
+using UKRailwayStationCode = AlphaId<uint16_t, 3>;
 }
 }
